@@ -8,6 +8,8 @@
 # -------
 
 import partialsmiles as ps
+from pysmiles import read_smiles
+from molvs import validate_smiles
 
 # RDKit Imports
 # -------------
@@ -25,7 +27,7 @@ class PartialSmilesValidation(object):
 
         self.partial = partial
 
-    def validate(self, smiles_list, partial_smiles=True, rdkit=True):
+    def validate(self, smiles_list, partial_smiles=True, rdkit=True, pysmiles=True, molvs=True):
 
         '''
 
@@ -33,6 +35,10 @@ class PartialSmilesValidation(object):
 
         Arguments:
             smiles_list (List): List of SMILES that the user would like to put
+            partial_smiles (Bool): Partial SMILES
+            rdkit (Bool): whether to include rdkit
+            pysmiles (Bool): whether to include pysmiles
+            molvs (Bool): whether to include molvs
 
         Returns:
             successes (List): List of SMILES that worked
@@ -50,10 +56,13 @@ class PartialSmilesValidation(object):
                     mol = ps.ParseSmiles(smiles, partial=self.partial)
                 if rdkit:
                     mol = Chem.MolFromSmiles(smiles)
+                if pysmiles:
+                    mol = read_smiles(smiles)
+                if molvs:
+                    errors = validate_smiles(smiles)
+                    print (errors)
                 successes.append(smiles)
             except:
                 failures.append(smiles)
 
-
-
         return successes, failures
\ No newline at end of file
